import reflex as rx


class AiFillAccountBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAccountBook"


class AiFillAlert(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAlert"


class AiFillAlipayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAlipayCircle"


class AiFillAlipaySquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAlipaySquare"


class AiFillAliwangwang(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAliwangwang"


class AiFillAmazonCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAmazonCircle"


class AiFillAmazonSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAmazonSquare"


class AiFillAndroid(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAndroid"


class AiFillApi(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillApi"


class AiFillApple(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillApple"


class AiFillAppstore(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAppstore"


class AiFillAudio(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillAudio"


class AiFillBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBackward"


class AiFillBank(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBank"


class AiFillBehanceCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBehanceCircle"


class AiFillBehanceSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBehanceSquare"


class AiFillBell(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBell"


class AiFillBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBook"


class AiFillBoxPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBoxPlot"


class AiFillBug(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBug"


class AiFillBuild(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBuild"


class AiFillBulb(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillBulb"


class AiFillCalculator(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCalculator"


class AiFillCalendar(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCalendar"


class AiFillCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCamera"


class AiFillCar(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCar"


class AiFillCaretDown(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCaretDown"


class AiFillCaretLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCaretLeft"


class AiFillCaretRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCaretRight"


class AiFillCaretUp(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCaretUp"


class AiFillCarryOut(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCarryOut"


class AiFillCheckCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCheckCircle"


class AiFillCheckSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCheckSquare"


class AiFillChrome(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillChrome"


class AiFillCiCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCiCircle"


class AiFillClockCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillClockCircle"


class AiFillCloseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCloseCircle"


class AiFillCloseSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCloseSquare"


class AiFillCloud(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCloud"


class AiFillCodeSandboxCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCodeSandboxCircle"


class AiFillCodeSandboxSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCodeSandboxSquare"


class AiFillCode(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCode"


class AiFillCodepenCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCodepenCircle"


class AiFillCodepenSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCodepenSquare"


class AiFillCompass(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCompass"


class AiFillContacts(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillContacts"


class AiFillContainer(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillContainer"


class AiFillControl(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillControl"


class AiFillCopy(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCopy"


class AiFillCopyrightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCopyrightCircle"


class AiFillCreditCard(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCreditCard"


class AiFillCrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCrown"


class AiFillCustomerService(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillCustomerService"


class AiFillDashboard(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDashboard"


class AiFillDatabase(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDatabase"


class AiFillDelete(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDelete"


class AiFillDiff(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDiff"


class AiFillDingtalkCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDingtalkCircle"


class AiFillDingtalkSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDingtalkSquare"


class AiFillDislike(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDislike"


class AiFillDollarCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDollarCircle"


class AiFillDownCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDownCircle"


class AiFillDownSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDownSquare"


class AiFillDribbbleCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDribbbleCircle"


class AiFillDribbbleSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDribbbleSquare"


class AiFillDropboxCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDropboxCircle"


class AiFillDropboxSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillDropboxSquare"


class AiFillEdit(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillEdit"


class AiFillEnvironment(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillEnvironment"


class AiFillEuroCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillEuroCircle"


class AiFillExclamationCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillExclamationCircle"


class AiFillExperiment(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillExperiment"


class AiFillEyeInvisible(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillEyeInvisible"


class AiFillEye(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillEye"


class AiFillFacebook(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFacebook"


class AiFillFastBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFastBackward"


class AiFillFastForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFastForward"


class AiFillFileAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileAdd"


class AiFillFileExcel(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileExcel"


class AiFillFileExclamation(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileExclamation"


class AiFillFileImage(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileImage"


class AiFillFileMarkdown(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileMarkdown"


class AiFillFilePdf(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFilePdf"


class AiFillFilePpt(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFilePpt"


class AiFillFileText(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileText"


class AiFillFileUnknown(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileUnknown"


class AiFillFileWord(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileWord"


class AiFillFileZip(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFileZip"


class AiFillFile(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFile"


class AiFillFilter(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFilter"


class AiFillFire(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFire"


class AiFillFlag(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFlag"


class AiFillFolderAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFolderAdd"


class AiFillFolderOpen(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFolderOpen"


class AiFillFolder(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFolder"


class AiFillFormatPainter(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFormatPainter"


class AiFillForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillForward"


class AiFillFrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFrown"


class AiFillFund(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFund"


class AiFillFunnelPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillFunnelPlot"


class AiFillGift(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGift"


class AiFillGithub(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGithub"


class AiFillGitlab(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGitlab"


class AiFillGold(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGold"


class AiFillGolden(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGolden"


class AiFillGoogleCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGoogleCircle"


class AiFillGooglePlusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGooglePlusCircle"


class AiFillGooglePlusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGooglePlusSquare"


class AiFillGoogleSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillGoogleSquare"


class AiFillHdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHdd"


class AiFillHeart(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHeart"


class AiFillHighlight(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHighlight"


class AiFillHome(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHome"


class AiFillHourglass(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHourglass"


class AiFillHtml5(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillHtml5"


class AiFillIdcard(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillIdcard"


class AiFillIeCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillIeCircle"


class AiFillIeSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillIeSquare"


class AiFillInfoCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillInfoCircle"


class AiFillInstagram(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillInstagram"


class AiFillInsurance(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillInsurance"


class AiFillInteraction(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillInteraction"


class AiFillLayout(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLayout"


class AiFillLeftCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLeftCircle"


class AiFillLeftSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLeftSquare"


class AiFillLike(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLike"


class AiFillLinkedin(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLinkedin"


class AiFillLock(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillLock"


class AiFillMacCommand(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMacCommand"


class AiFillMail(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMail"


class AiFillMedicineBox(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMedicineBox"


class AiFillMediumCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMediumCircle"


class AiFillMediumSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMediumSquare"


class AiFillMeh(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMeh"


class AiFillMessage(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMessage"


class AiFillMinusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMinusCircle"


class AiFillMinusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMinusSquare"


class AiFillMobile(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMobile"


class AiFillMoneyCollect(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillMoneyCollect"


class AiFillNotification(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillNotification"


class AiFillPauseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPauseCircle"


class AiFillPayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPayCircle"


class AiFillPhone(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPhone"


class AiFillPicture(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPicture"


class AiFillPieChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPieChart"


class AiFillPlayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPlayCircle"


class AiFillPlaySquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPlaySquare"


class AiFillPlusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPlusCircle"


class AiFillPlusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPlusSquare"


class AiFillPoundCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPoundCircle"


class AiFillPrinter(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPrinter"


class AiFillProfile(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillProfile"


class AiFillProject(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillProject"


class AiFillPropertySafety(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPropertySafety"


class AiFillPushpin(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillPushpin"


class AiFillQqCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillQqCircle"


class AiFillQqSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillQqSquare"


class AiFillQuestionCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillQuestionCircle"


class AiFillRead(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRead"


class AiFillReconciliation(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillReconciliation"


class AiFillRedEnvelope(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRedEnvelope"


class AiFillRedditCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRedditCircle"


class AiFillRedditSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRedditSquare"


class AiFillRest(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRest"


class AiFillRightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRightCircle"


class AiFillRightSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRightSquare"


class AiFillRobot(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRobot"


class AiFillRocket(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillRocket"


class AiFillSafetyCertificate(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSafetyCertificate"


class AiFillSave(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSave"


class AiFillSchedule(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSchedule"


class AiFillSecurityScan(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSecurityScan"


class AiFillSetting(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSetting"


class AiFillShop(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillShop"


class AiFillShopping(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillShopping"


class AiFillSignal(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSignal"


class AiFillSketchCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSketchCircle"


class AiFillSketchSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSketchSquare"


class AiFillSkin(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSkin"


class AiFillSkype(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSkype"


class AiFillSlackCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSlackCircle"


class AiFillSlackSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSlackSquare"


class AiFillSliders(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSliders"


class AiFillSmile(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSmile"


class AiFillSnippets(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSnippets"


class AiFillSound(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSound"


class AiFillStar(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillStar"


class AiFillStepBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillStepBackward"


class AiFillStepForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillStepForward"


class AiFillStop(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillStop"


class AiFillSwitcher(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillSwitcher"


class AiFillTablet(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTablet"


class AiFillTag(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTag"


class AiFillTags(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTags"


class AiFillTaobaoCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTaobaoCircle"


class AiFillTaobaoSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTaobaoSquare"


class AiFillThunderbolt(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillThunderbolt"


class AiFillTool(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTool"


class AiFillTrademarkCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTrademarkCircle"


class AiFillTrophy(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTrophy"


class AiFillTwitterCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTwitterCircle"


class AiFillTwitterSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillTwitterSquare"


class AiFillUnlock(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillUnlock"


class AiFillUpCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillUpCircle"


class AiFillUpSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillUpSquare"


class AiFillUsb(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillUsb"


class AiFillVideoCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillVideoCamera"


class AiFillWallet(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWallet"


class AiFillWarning(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWarning"


class AiFillWechat(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWechat"


class AiFillWeiboCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWeiboCircle"


class AiFillWeiboSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWeiboSquare"


class AiFillWindows(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillWindows"


class AiFillYahoo(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillYahoo"


class AiFillYoutube(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillYoutube"


class AiFillYuque(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillYuque"


class AiFillZhihuCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillZhihuCircle"


class AiFillZhihuSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiFillZhihuSquare"


class AiOutlineAccountBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAccountBook"


class AiOutlineAim(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAim"


class AiOutlineAlert(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlert"


class AiOutlineAlibaba(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlibaba"


class AiOutlineAlignCenter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlignCenter"


class AiOutlineAlignLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlignLeft"


class AiOutlineAlignRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlignRight"


class AiOutlineAlipayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlipayCircle"


class AiOutlineAlipay(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAlipay"


class AiOutlineAliwangwang(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAliwangwang"


class AiOutlineAliyun(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAliyun"


class AiOutlineAmazon(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAmazon"


class AiOutlineAndroid(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAndroid"


class AiOutlineAntCloud(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAntCloud"


class AiOutlineAntDesign(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAntDesign"


class AiOutlineApartment(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineApartment"


class AiOutlineApi(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineApi"


class AiOutlineApple(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineApple"


class AiOutlineAppstoreAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAppstoreAdd"


class AiOutlineAppstore(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAppstore"


class AiOutlineAreaChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAreaChart"


class AiOutlineArrowDown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineArrowDown"


class AiOutlineArrowLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineArrowLeft"


class AiOutlineArrowRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineArrowRight"


class AiOutlineArrowUp(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineArrowUp"


class AiOutlineArrowsAlt(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineArrowsAlt"


class AiOutlineAudioMuted(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAudioMuted"


class AiOutlineAudio(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAudio"


class AiOutlineAudit(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineAudit"


class AiOutlineBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBackward"


class AiOutlineBank(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBank"


class AiOutlineBarChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBarChart"


class AiOutlineBarcode(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBarcode"


class AiOutlineBars(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBars"


class AiOutlineBehanceSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBehanceSquare"


class AiOutlineBehance(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBehance"


class AiOutlineBell(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBell"


class AiOutlineBgColors(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBgColors"


class AiOutlineBlock(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBlock"


class AiOutlineBold(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBold"


class AiOutlineBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBook"


class AiOutlineBorderBottom(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderBottom"


class AiOutlineBorderHorizontal(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderHorizontal"


class AiOutlineBorderInner(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderInner"


class AiOutlineBorderLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderLeft"


class AiOutlineBorderOuter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderOuter"


class AiOutlineBorderRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderRight"


class AiOutlineBorderTop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderTop"


class AiOutlineBorderVerticle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderVerticle"


class AiOutlineBorder(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorder"


class AiOutlineBorderlessTable(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBorderlessTable"


class AiOutlineBoxPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBoxPlot"


class AiOutlineBranches(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBranches"


class AiOutlineBug(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBug"


class AiOutlineBuild(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBuild"


class AiOutlineBulb(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineBulb"


class AiOutlineCalculator(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCalculator"


class AiOutlineCalendar(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCalendar"


class AiOutlineCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCamera"


class AiOutlineCar(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCar"


class AiOutlineCaretDown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCaretDown"


class AiOutlineCaretLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCaretLeft"


class AiOutlineCaretRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCaretRight"


class AiOutlineCaretUp(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCaretUp"


class AiOutlineCarryOut(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCarryOut"


class AiOutlineCheckCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCheckCircle"


class AiOutlineCheckSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCheckSquare"


class AiOutlineCheck(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCheck"


class AiOutlineChrome(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineChrome"


class AiOutlineCiCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCiCircle"


class AiOutlineCi(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCi"


class AiOutlineClear(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineClear"


class AiOutlineClockCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineClockCircle"


class AiOutlineCloseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloseCircle"


class AiOutlineCloseSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloseSquare"


class AiOutlineClose(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineClose"


class AiOutlineCloudDownload(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloudDownload"


class AiOutlineCloudServer(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloudServer"


class AiOutlineCloudSync(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloudSync"


class AiOutlineCloudUpload(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloudUpload"


class AiOutlineCloud(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCloud"


class AiOutlineCluster(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCluster"


class AiOutlineCodeSandbox(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCodeSandbox"


class AiOutlineCode(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCode"


class AiOutlineCodepenCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCodepenCircle"


class AiOutlineCodepen(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCodepen"


class AiOutlineCoffee(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCoffee"


class AiOutlineColumnHeight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineColumnHeight"


class AiOutlineColumnWidth(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineColumnWidth"


class AiOutlineComment(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineComment"


class AiOutlineCompass(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCompass"


class AiOutlineCompress(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCompress"


class AiOutlineConsoleSql(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineConsoleSql"


class AiOutlineContacts(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineContacts"


class AiOutlineContainer(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineContainer"


class AiOutlineControl(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineControl"


class AiOutlineCopy(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCopy"


class AiOutlineCopyrightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCopyrightCircle"


class AiOutlineCopyright(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCopyright"


class AiOutlineCreditCard(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCreditCard"


class AiOutlineCrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCrown"


class AiOutlineCustomerService(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineCustomerService"


class AiOutlineDash(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDash"


class AiOutlineDashboard(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDashboard"


class AiOutlineDatabase(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDatabase"


class AiOutlineDeleteColumn(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDeleteColumn"


class AiOutlineDeleteRow(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDeleteRow"


class AiOutlineDelete(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDelete"


class AiOutlineDeliveredProcedure(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDeliveredProcedure"


class AiOutlineDeploymentUnit(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDeploymentUnit"


class AiOutlineDesktop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDesktop"


class AiOutlineDiff(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDiff"


class AiOutlineDingding(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDingding"


class AiOutlineDingtalk(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDingtalk"


class AiOutlineDisconnect(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDisconnect"


class AiOutlineDislike(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDislike"


class AiOutlineDollarCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDollarCircle"


class AiOutlineDollar(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDollar"


class AiOutlineDotChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDotChart"


class AiOutlineDoubleLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDoubleLeft"


class AiOutlineDoubleRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDoubleRight"


class AiOutlineDownCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDownCircle"


class AiOutlineDownSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDownSquare"


class AiOutlineDown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDown"


class AiOutlineDownload(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDownload"


class AiOutlineDrag(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDrag"


class AiOutlineDribbbleSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDribbbleSquare"


class AiOutlineDribbble(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDribbble"


class AiOutlineDropbox(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineDropbox"


class AiOutlineEdit(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEdit"


class AiOutlineEllipsis(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEllipsis"


class AiOutlineEnter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEnter"


class AiOutlineEnvironment(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEnvironment"


class AiOutlineEuroCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEuroCircle"


class AiOutlineEuro(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEuro"


class AiOutlineException(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineException"


class AiOutlineExclamationCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExclamationCircle"


class AiOutlineExclamation(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExclamation"


class AiOutlineExpandAlt(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExpandAlt"


class AiOutlineExpand(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExpand"


class AiOutlineExperiment(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExperiment"


class AiOutlineExport(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineExport"


class AiOutlineEyeInvisible(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEyeInvisible"


class AiOutlineEye(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineEye"


class AiOutlineFacebook(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFacebook"


class AiOutlineFall(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFall"


class AiOutlineFastBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFastBackward"


class AiOutlineFastForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFastForward"


class AiOutlineFieldBinary(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFieldBinary"


class AiOutlineFieldNumber(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFieldNumber"


class AiOutlineFieldString(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFieldString"


class AiOutlineFieldTime(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFieldTime"


class AiOutlineFileAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileAdd"


class AiOutlineFileDone(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileDone"


class AiOutlineFileExcel(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileExcel"


class AiOutlineFileExclamation(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileExclamation"


class AiOutlineFileGif(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileGif"


class AiOutlineFileImage(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileImage"


class AiOutlineFileJpg(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileJpg"


class AiOutlineFileMarkdown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileMarkdown"


class AiOutlineFilePdf(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFilePdf"


class AiOutlineFilePpt(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFilePpt"


class AiOutlineFileProtect(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileProtect"


class AiOutlineFileSearch(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileSearch"


class AiOutlineFileSync(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileSync"


class AiOutlineFileText(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileText"


class AiOutlineFileUnknown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileUnknown"


class AiOutlineFileWord(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileWord"


class AiOutlineFileZip(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFileZip"


class AiOutlineFile(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFile"


class AiOutlineFilter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFilter"


class AiOutlineFire(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFire"


class AiOutlineFlag(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFlag"


class AiOutlineFolderAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFolderAdd"


class AiOutlineFolderOpen(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFolderOpen"


class AiOutlineFolderView(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFolderView"


class AiOutlineFolder(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFolder"


class AiOutlineFontColors(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFontColors"


class AiOutlineFontSize(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFontSize"


class AiOutlineFork(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFork"


class AiOutlineForm(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineForm"


class AiOutlineFormatPainter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFormatPainter"


class AiOutlineForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineForward"


class AiOutlineFrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFrown"


class AiOutlineFullscreenExit(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFullscreenExit"


class AiOutlineFullscreen(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFullscreen"


class AiOutlineFunction(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFunction"


class AiOutlineFundProjectionScreen(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFundProjectionScreen"


class AiOutlineFundView(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFundView"


class AiOutlineFund(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFund"


class AiOutlineFunnelPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineFunnelPlot"


class AiOutlineGateway(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGateway"


class AiOutlineGif(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGif"


class AiOutlineGift(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGift"


class AiOutlineGithub(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGithub"


class AiOutlineGitlab(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGitlab"


class AiOutlineGlobal(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGlobal"


class AiOutlineGold(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGold"


class AiOutlineGooglePlus(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGooglePlus"


class AiOutlineGoogle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGoogle"


class AiOutlineGroup(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineGroup"


class AiOutlineHdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHdd"


class AiOutlineHeart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHeart"


class AiOutlineHeatMap(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHeatMap"


class AiOutlineHighlight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHighlight"


class AiOutlineHistory(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHistory"


class AiOutlineHolder(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHolder"


class AiOutlineHome(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHome"


class AiOutlineHourglass(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHourglass"


class AiOutlineHtml5(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineHtml5"


class AiOutlineIdcard(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineIdcard"


class AiOutlineIe(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineIe"


class AiOutlineImport(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineImport"


class AiOutlineInbox(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInbox"


class AiOutlineInfoCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInfoCircle"


class AiOutlineInfo(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInfo"


class AiOutlineInsertRowAbove(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInsertRowAbove"


class AiOutlineInsertRowBelow(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInsertRowBelow"


class AiOutlineInsertRowLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInsertRowLeft"


class AiOutlineInsertRowRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInsertRowRight"


class AiOutlineInstagram(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInstagram"


class AiOutlineInsurance(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInsurance"


class AiOutlineInteraction(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineInteraction"


class AiOutlineIssuesClose(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineIssuesClose"


class AiOutlineItalic(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineItalic"


class AiOutlineKey(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineKey"


class AiOutlineLaptop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLaptop"


class AiOutlineLayout(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLayout"


class AiOutlineLeftCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLeftCircle"


class AiOutlineLeftSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLeftSquare"


class AiOutlineLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLeft"


class AiOutlineLike(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLike"


class AiOutlineLineChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLineChart"


class AiOutlineLineHeight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLineHeight"


class AiOutlineLine(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLine"


class AiOutlineLink(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLink"


class AiOutlineLinkedin(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLinkedin"


class AiOutlineLoading3Quarters(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLoading3Quarters"


class AiOutlineLoading(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLoading"


class AiOutlineLock(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLock"


class AiOutlineLogin(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLogin"


class AiOutlineLogout(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineLogout"


class AiOutlineMacCommand(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMacCommand"


class AiOutlineMail(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMail"


class AiOutlineMan(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMan"


class AiOutlineMedicineBox(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMedicineBox"


class AiOutlineMediumWorkmark(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMediumWorkmark"


class AiOutlineMedium(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMedium"


class AiOutlineMeh(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMeh"


class AiOutlineMenuFold(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMenuFold"


class AiOutlineMenuUnfold(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMenuUnfold"


class AiOutlineMenu(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMenu"


class AiOutlineMergeCells(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMergeCells"


class AiOutlineMessage(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMessage"


class AiOutlineMinusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMinusCircle"


class AiOutlineMinusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMinusSquare"


class AiOutlineMinus(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMinus"


class AiOutlineMobile(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMobile"


class AiOutlineMoneyCollect(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMoneyCollect"


class AiOutlineMonitor(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMonitor"


class AiOutlineMore(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineMore"


class AiOutlineNodeCollapse(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineNodeCollapse"


class AiOutlineNodeExpand(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineNodeExpand"


class AiOutlineNodeIndex(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineNodeIndex"


class AiOutlineNotification(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineNotification"


class AiOutlineNumber(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineNumber"


class AiOutlineOneToOne(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineOneToOne"


class AiOutlineOrderedList(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineOrderedList"


class AiOutlinePaperClip(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePaperClip"


class AiOutlinePartition(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePartition"


class AiOutlinePauseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePauseCircle"


class AiOutlinePause(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePause"


class AiOutlinePayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePayCircle"


class AiOutlinePercentage(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePercentage"


class AiOutlinePhone(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePhone"


class AiOutlinePicCenter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePicCenter"


class AiOutlinePicLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePicLeft"


class AiOutlinePicRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePicRight"


class AiOutlinePicture(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePicture"


class AiOutlinePieChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePieChart"


class AiOutlinePlayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePlayCircle"


class AiOutlinePlaySquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePlaySquare"


class AiOutlinePlusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePlusCircle"


class AiOutlinePlusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePlusSquare"


class AiOutlinePlus(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePlus"


class AiOutlinePoundCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePoundCircle"


class AiOutlinePound(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePound"


class AiOutlinePoweroff(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePoweroff"


class AiOutlinePrinter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePrinter"


class AiOutlineProfile(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineProfile"


class AiOutlineProject(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineProject"


class AiOutlinePropertySafety(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePropertySafety"


class AiOutlinePullRequest(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePullRequest"


class AiOutlinePushpin(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlinePushpin"


class AiOutlineQq(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineQq"


class AiOutlineQrcode(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineQrcode"


class AiOutlineQuestionCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineQuestionCircle"


class AiOutlineQuestion(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineQuestion"


class AiOutlineRadarChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadarChart"


class AiOutlineRadiusBottomleft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadiusBottomleft"


class AiOutlineRadiusBottomright(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadiusBottomright"


class AiOutlineRadiusSetting(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadiusSetting"


class AiOutlineRadiusUpleft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadiusUpleft"


class AiOutlineRadiusUpright(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRadiusUpright"


class AiOutlineRead(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRead"


class AiOutlineReconciliation(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineReconciliation"


class AiOutlineRedEnvelope(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRedEnvelope"


class AiOutlineReddit(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineReddit"


class AiOutlineRedo(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRedo"


class AiOutlineReload(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineReload"


class AiOutlineRest(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRest"


class AiOutlineRetweet(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRetweet"


class AiOutlineRightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRightCircle"


class AiOutlineRightSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRightSquare"


class AiOutlineRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRight"


class AiOutlineRise(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRise"


class AiOutlineRobot(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRobot"


class AiOutlineRocket(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRocket"


class AiOutlineRollback(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRollback"


class AiOutlineRotateLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRotateLeft"


class AiOutlineRotateRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineRotateRight"


class AiOutlineSafetyCertificate(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSafetyCertificate"


class AiOutlineSafety(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSafety"


class AiOutlineSave(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSave"


class AiOutlineScan(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineScan"


class AiOutlineSchedule(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSchedule"


class AiOutlineScissor(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineScissor"


class AiOutlineSearch(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSearch"


class AiOutlineSecurityScan(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSecurityScan"


class AiOutlineSelect(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSelect"


class AiOutlineSend(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSend"


class AiOutlineSetting(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSetting"


class AiOutlineShake(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShake"


class AiOutlineShareAlt(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShareAlt"


class AiOutlineShop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShop"


class AiOutlineShoppingCart(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShoppingCart"


class AiOutlineShopping(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShopping"


class AiOutlineShrink(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineShrink"


class AiOutlineSisternode(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSisternode"


class AiOutlineSketch(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSketch"


class AiOutlineSkin(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSkin"


class AiOutlineSkype(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSkype"


class AiOutlineSlackSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSlackSquare"


class AiOutlineSlack(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSlack"


class AiOutlineSliders(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSliders"


class AiOutlineSmallDash(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSmallDash"


class AiOutlineSmile(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSmile"


class AiOutlineSnippets(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSnippets"


class AiOutlineSolution(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSolution"


class AiOutlineSortAscending(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSortAscending"


class AiOutlineSortDescending(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSortDescending"


class AiOutlineSound(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSound"


class AiOutlineSplitCells(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSplitCells"


class AiOutlineStar(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStar"


class AiOutlineStepBackward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStepBackward"


class AiOutlineStepForward(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStepForward"


class AiOutlineStock(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStock"


class AiOutlineStop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStop"


class AiOutlineStrikethrough(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineStrikethrough"


class AiOutlineSubnode(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSubnode"


class AiOutlineSwapLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSwapLeft"


class AiOutlineSwapRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSwapRight"


class AiOutlineSwap(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSwap"


class AiOutlineSwitcher(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSwitcher"


class AiOutlineSync(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineSync"


class AiOutlineTable(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTable"


class AiOutlineTablet(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTablet"


class AiOutlineTag(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTag"


class AiOutlineTags(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTags"


class AiOutlineTaobaoCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTaobaoCircle"


class AiOutlineTaobao(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTaobao"


class AiOutlineTeam(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTeam"


class AiOutlineThunderbolt(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineThunderbolt"


class AiOutlineToTop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineToTop"


class AiOutlineTool(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTool"


class AiOutlineTrademarkCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTrademarkCircle"


class AiOutlineTrademark(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTrademark"


class AiOutlineTransaction(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTransaction"


class AiOutlineTranslation(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTranslation"


class AiOutlineTrophy(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTrophy"


class AiOutlineTwitter(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineTwitter"


class AiOutlineUnderline(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUnderline"


class AiOutlineUndo(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUndo"


class AiOutlineUngroup(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUngroup"


class AiOutlineUnlock(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUnlock"


class AiOutlineUnorderedList(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUnorderedList"


class AiOutlineUpCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUpCircle"


class AiOutlineUpSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUpSquare"


class AiOutlineUp(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUp"


class AiOutlineUpload(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUpload"


class AiOutlineUsb(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUsb"


class AiOutlineUserAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUserAdd"


class AiOutlineUserDelete(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUserDelete"


class AiOutlineUserSwitch(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUserSwitch"


class AiOutlineUser(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUser"


class AiOutlineUsergroupAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUsergroupAdd"


class AiOutlineUsergroupDelete(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineUsergroupDelete"


class AiOutlineVerified(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerified"


class AiOutlineVerticalAlignBottom(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerticalAlignBottom"


class AiOutlineVerticalAlignMiddle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerticalAlignMiddle"


class AiOutlineVerticalAlignTop(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerticalAlignTop"


class AiOutlineVerticalLeft(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerticalLeft"


class AiOutlineVerticalRight(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVerticalRight"


class AiOutlineVideoCameraAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVideoCameraAdd"


class AiOutlineVideoCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineVideoCamera"


class AiOutlineWallet(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWallet"


class AiOutlineWarning(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWarning"


class AiOutlineWechat(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWechat"


class AiOutlineWeiboCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWeiboCircle"


class AiOutlineWeiboSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWeiboSquare"


class AiOutlineWeibo(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWeibo"


class AiOutlineWhatsApp(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWhatsApp"


class AiOutlineWifi(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWifi"


class AiOutlineWindows(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWindows"


class AiOutlineWoman(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineWoman"


class AiOutlineYahoo(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineYahoo"


class AiOutlineYoutube(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineYoutube"


class AiOutlineYuque(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineYuque"


class AiOutlineZhihu(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineZhihu"


class AiOutlineZoomIn(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineZoomIn"


class AiOutlineZoomOut(rx.Component):
    library = "react-icons/ai"
    tag = "AiOutlineZoomOut"


class AiTwotoneAccountBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneAccountBook"


class AiTwotoneAlert(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneAlert"


class AiTwotoneApi(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneApi"


class AiTwotoneAppstore(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneAppstore"


class AiTwotoneAudio(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneAudio"


class AiTwotoneBank(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBank"


class AiTwotoneBell(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBell"


class AiTwotoneBook(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBook"


class AiTwotoneBoxPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBoxPlot"


class AiTwotoneBug(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBug"


class AiTwotoneBuild(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBuild"


class AiTwotoneBulb(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneBulb"


class AiTwotoneCalculator(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCalculator"


class AiTwotoneCalendar(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCalendar"


class AiTwotoneCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCamera"


class AiTwotoneCar(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCar"


class AiTwotoneCarryOut(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCarryOut"


class AiTwotoneCheckCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCheckCircle"


class AiTwotoneCheckSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCheckSquare"


class AiTwotoneCiCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCiCircle"


class AiTwotoneCi(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCi"


class AiTwotoneClockCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneClockCircle"


class AiTwotoneCloseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCloseCircle"


class AiTwotoneCloseSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCloseSquare"


class AiTwotoneCloud(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCloud"


class AiTwotoneCode(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCode"


class AiTwotoneCompass(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCompass"


class AiTwotoneContacts(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneContacts"


class AiTwotoneContainer(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneContainer"


class AiTwotoneControl(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneControl"


class AiTwotoneCopy(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCopy"


class AiTwotoneCopyrightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCopyrightCircle"


class AiTwotoneCopyright(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCopyright"


class AiTwotoneCreditCard(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCreditCard"


class AiTwotoneCrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCrown"


class AiTwotoneCustomerService(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneCustomerService"


class AiTwotoneDashboard(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDashboard"


class AiTwotoneDatabase(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDatabase"


class AiTwotoneDelete(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDelete"


class AiTwotoneDiff(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDiff"


class AiTwotoneDislike(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDislike"


class AiTwotoneDollarCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDollarCircle"


class AiTwotoneDollar(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDollar"


class AiTwotoneDownCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDownCircle"


class AiTwotoneDownSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneDownSquare"


class AiTwotoneEdit(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEdit"


class AiTwotoneEnvironment(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEnvironment"


class AiTwotoneEuroCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEuroCircle"


class AiTwotoneEuro(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEuro"


class AiTwotoneExclamationCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneExclamationCircle"


class AiTwotoneExperiment(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneExperiment"


class AiTwotoneEyeInvisible(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEyeInvisible"


class AiTwotoneEye(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneEye"


class AiTwotoneFileAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileAdd"


class AiTwotoneFileExcel(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileExcel"


class AiTwotoneFileExclamation(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileExclamation"


class AiTwotoneFileImage(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileImage"


class AiTwotoneFileMarkdown(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileMarkdown"


class AiTwotoneFilePdf(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFilePdf"


class AiTwotoneFilePpt(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFilePpt"


class AiTwotoneFileText(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileText"


class AiTwotoneFileUnknown(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileUnknown"


class AiTwotoneFileWord(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileWord"


class AiTwotoneFileZip(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFileZip"


class AiTwotoneFile(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFile"


class AiTwotoneFilter(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFilter"


class AiTwotoneFire(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFire"


class AiTwotoneFlag(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFlag"


class AiTwotoneFolderAdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFolderAdd"


class AiTwotoneFolderOpen(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFolderOpen"


class AiTwotoneFolder(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFolder"


class AiTwotoneFrown(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFrown"


class AiTwotoneFund(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFund"


class AiTwotoneFunnelPlot(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneFunnelPlot"


class AiTwotoneGift(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneGift"


class AiTwotoneGold(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneGold"


class AiTwotoneHdd(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHdd"


class AiTwotoneHeart(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHeart"


class AiTwotoneHighlight(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHighlight"


class AiTwotoneHome(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHome"


class AiTwotoneHourglass(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHourglass"


class AiTwotoneHtml5(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneHtml5"


class AiTwotoneIdcard(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneIdcard"


class AiTwotoneInfoCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneInfoCircle"


class AiTwotoneInsurance(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneInsurance"


class AiTwotoneInteraction(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneInteraction"


class AiTwotoneLayout(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneLayout"


class AiTwotoneLeftCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneLeftCircle"


class AiTwotoneLeftSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneLeftSquare"


class AiTwotoneLike(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneLike"


class AiTwotoneLock(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneLock"


class AiTwotoneMail(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMail"


class AiTwotoneMedicineBox(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMedicineBox"


class AiTwotoneMeh(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMeh"


class AiTwotoneMessage(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMessage"


class AiTwotoneMinusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMinusCircle"


class AiTwotoneMinusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMinusSquare"


class AiTwotoneMobile(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMobile"


class AiTwotoneMoneyCollect(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneMoneyCollect"


class AiTwotoneNotification(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneNotification"


class AiTwotonePauseCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePauseCircle"


class AiTwotonePhone(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePhone"


class AiTwotonePicture(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePicture"


class AiTwotonePieChart(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePieChart"


class AiTwotonePlayCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePlayCircle"


class AiTwotonePlaySquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePlaySquare"


class AiTwotonePlusCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePlusCircle"


class AiTwotonePlusSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePlusSquare"


class AiTwotonePoundCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePoundCircle"


class AiTwotonePrinter(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePrinter"


class AiTwotoneProfile(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneProfile"


class AiTwotoneProject(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneProject"


class AiTwotonePropertySafety(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePropertySafety"


class AiTwotonePushpin(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotonePushpin"


class AiTwotoneQuestionCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneQuestionCircle"


class AiTwotoneReconciliation(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneReconciliation"


class AiTwotoneRedEnvelope(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneRedEnvelope"


class AiTwotoneRest(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneRest"


class AiTwotoneRightCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneRightCircle"


class AiTwotoneRightSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneRightSquare"


class AiTwotoneRocket(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneRocket"


class AiTwotoneSafetyCertificate(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSafetyCertificate"


class AiTwotoneSave(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSave"


class AiTwotoneSchedule(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSchedule"


class AiTwotoneSecurityScan(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSecurityScan"


class AiTwotoneSetting(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSetting"


class AiTwotoneShop(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneShop"


class AiTwotoneShopping(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneShopping"


class AiTwotoneSkin(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSkin"


class AiTwotoneSliders(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSliders"


class AiTwotoneSmile(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSmile"


class AiTwotoneSnippets(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSnippets"


class AiTwotoneSound(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSound"


class AiTwotoneStar(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneStar"


class AiTwotoneStop(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneStop"


class AiTwotoneSwitcher(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneSwitcher"


class AiTwotoneTablet(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTablet"


class AiTwotoneTag(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTag"


class AiTwotoneTags(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTags"


class AiTwotoneThunderbolt(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneThunderbolt"


class AiTwotoneTool(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTool"


class AiTwotoneTrademarkCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTrademarkCircle"


class AiTwotoneTrophy(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneTrophy"


class AiTwotoneUnlock(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneUnlock"


class AiTwotoneUpCircle(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneUpCircle"


class AiTwotoneUpSquare(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneUpSquare"


class AiTwotoneUsb(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneUsb"


class AiTwotoneVideoCamera(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneVideoCamera"


class AiTwotoneWallet(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneWallet"


class AiTwotoneWarning(rx.Component):
    library = "react-icons/ai"
    tag = "AiTwotoneWarning"





import reflex as rx

class CiAirportSign1(rx.Component):
    library = "react-icons/ci"
    tag = "CiAirportSign1"


class CiAlarmOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlarmOff"


class CiAlarmOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlarmOn"


class CiAlignBottom(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignBottom"


class CiAlignCenterH(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignCenterH"


class CiAlignCenterV(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignCenterV"


class CiAlignLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignLeft"


class CiAlignRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignRight"


class CiAlignTop(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignTop"


class CiApple(rx.Component):
    library = "react-icons/ci"
    tag = "CiApple"


class CiAt(rx.Component):
    library = "react-icons/ci"
    tag = "CiAt"


class CiAvocado(rx.Component):
    library = "react-icons/ci"
    tag = "CiAvocado"


class CiBacon(rx.Component):
    library = "react-icons/ci"
    tag = "CiBacon"


class CiBadgeDollar(rx.Component):
    library = "react-icons/ci"
    tag = "CiBadgeDollar"


class CiBag1(rx.Component):
    library = "react-icons/ci"
    tag = "CiBag1"


class CiBandage(rx.Component):
    library = "react-icons/ci"
    tag = "CiBandage"


class CiBank(rx.Component):
    library = "react-icons/ci"
    tag = "CiBank"


class CiBarcode(rx.Component):
    library = "react-icons/ci"
    tag = "CiBarcode"


class CiBaseball(rx.Component):
    library = "react-icons/ci"
    tag = "CiBaseball"


class CiBasketball(rx.Component):
    library = "react-icons/ci"
    tag = "CiBasketball"


class CiBatteryCharging(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryCharging"


class CiBatteryEmpty(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryEmpty"


class CiBatteryFull(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryFull"


class CiBeaker1(rx.Component):
    library = "react-icons/ci"
    tag = "CiBeaker1"


class CiBeerMugFull(rx.Component):
    library = "react-icons/ci"
    tag = "CiBeerMugFull"


class CiBellOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiBellOff"


class CiBellOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiBellOn"


class CiBezier(rx.Component):
    library = "react-icons/ci"
    tag = "CiBezier"


class CiBitcoin(rx.Component):
    library = "react-icons/ci"
    tag = "CiBitcoin"


class CiBluetooth(rx.Component):
    library = "react-icons/ci"
    tag = "CiBluetooth"


class CiBookmarkCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkCheck"


class CiBookmarkMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkMinus"


class CiBookmarkPlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkPlus"


class CiBookmarkRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkRemove"


class CiBookmark(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmark"


class CiBowlNoodles(rx.Component):
    library = "react-icons/ci"
    tag = "CiBowlNoodles"


class CiBoxList(rx.Component):
    library = "react-icons/ci"
    tag = "CiBoxList"


class CiBoxes(rx.Component):
    library = "react-icons/ci"
    tag = "CiBoxes"


class CiBrightnessDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiBrightnessDown"


class CiBrightnessUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiBrightnessUp"


class CiBullhorn(rx.Component):
    library = "react-icons/ci"
    tag = "CiBullhorn"


class CiBurger(rx.Component):
    library = "react-icons/ci"
    tag = "CiBurger"


class CiCalculator1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalculator1"


class CiCalculator2(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalculator2"


class CiCalendarDate(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalendarDate"


class CiCalendar(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalendar"


class CiCamera(rx.Component):
    library = "react-icons/ci"
    tag = "CiCamera"


class CiChat1(rx.Component):
    library = "react-icons/ci"
    tag = "CiChat1"


class CiChat2(rx.Component):
    library = "react-icons/ci"
    tag = "CiChat2"


class CiCircleAlert(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleAlert"


class CiCircleCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleCheck"


class CiCircleChevDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevDown"


class CiCircleChevLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevLeft"


class CiCircleChevRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevRight"


class CiCircleChevUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevUp"


class CiCircleInfo(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleInfo"


class CiCircleList(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleList"


class CiCircleMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleMinus"


class CiCircleMore(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleMore"


class CiCirclePlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiCirclePlus"


class CiCircleQuestion(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleQuestion"


class CiCircleRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleRemove"


class CiClock1(rx.Component):
    library = "react-icons/ci"
    tag = "CiClock1"


class CiClock2(rx.Component):
    library = "react-icons/ci"
    tag = "CiClock2"


class CiCloudDrizzle(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudDrizzle"


class CiCloudMoon(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudMoon"


class CiCloudOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudOff"


class CiCloudOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudOn"


class CiCloudRainbow(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudRainbow"


class CiCloudSun(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudSun"


class CiCloud(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloud"


class CiCoffeeBean(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoffeeBean"


class CiCoffeeCup(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoffeeCup"


class CiCoinInsert(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoinInsert"


class CiCoins1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoins1"


class CiCompass1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCompass1"


class CiCreditCard1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCard1"


class CiCreditCard2(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCard2"


class CiCreditCardOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCardOff"


class CiCrop(rx.Component):
    library = "react-icons/ci"
    tag = "CiCrop"


class CiDark(rx.Component):
    library = "react-icons/ci"
    tag = "CiDark"


class CiDatabase(rx.Component):
    library = "react-icons/ci"
    tag = "CiDatabase"


class CiDeliveryTruck(rx.Component):
    library = "react-icons/ci"
    tag = "CiDeliveryTruck"


class CiDesktopMouse1(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktopMouse1"


class CiDesktopMouse2(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktopMouse2"


class CiDesktop(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktop"


class CiDiscount1(rx.Component):
    library = "react-icons/ci"
    tag = "CiDiscount1"


class CiDollar(rx.Component):
    library = "react-icons/ci"
    tag = "CiDollar"


class CiDroplet(rx.Component):
    library = "react-icons/ci"
    tag = "CiDroplet"


class CiDumbbell(rx.Component):
    library = "react-icons/ci"
    tag = "CiDumbbell"


class CiEdit(rx.Component):
    library = "react-icons/ci"
    tag = "CiEdit"


class CiEraser(rx.Component):
    library = "react-icons/ci"
    tag = "CiEraser"


class CiExport(rx.Component):
    library = "react-icons/ci"
    tag = "CiExport"


class CiFaceFrown(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceFrown"


class CiFaceMeh(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceMeh"


class CiFaceSmile(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceSmile"


class CiFacebook(rx.Component):
    library = "react-icons/ci"
    tag = "CiFacebook"


class CiFileOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiFileOff"


class CiFileOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiFileOn"


class CiFilter(rx.Component):
    library = "react-icons/ci"
    tag = "CiFilter"


class CiFlag1(rx.Component):
    library = "react-icons/ci"
    tag = "CiFlag1"


class CiFloppyDisk(rx.Component):
    library = "react-icons/ci"
    tag = "CiFloppyDisk"


class CiFolderOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiFolderOff"


class CiFolderOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiFolderOn"


class CiFootball(rx.Component):
    library = "react-icons/ci"
    tag = "CiFootball"


class CiForkAndKnife(rx.Component):
    library = "react-icons/ci"
    tag = "CiForkAndKnife"


class CiFries(rx.Component):
    library = "react-icons/ci"
    tag = "CiFries"


class CiGift(rx.Component):
    library = "react-icons/ci"
    tag = "CiGift"


class CiGlass(rx.Component):
    library = "react-icons/ci"
    tag = "CiGlass"


class CiGlobe(rx.Component):
    library = "react-icons/ci"
    tag = "CiGlobe"


class CiGps(rx.Component):
    library = "react-icons/ci"
    tag = "CiGps"


class CiGrid2H(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid2H"


class CiGrid2V(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid2V"


class CiGrid31(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid31"


class CiGrid32(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid32"


class CiGrid41(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid41"


class CiGrid42(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid42"


class CiHardDrive(rx.Component):
    library = "react-icons/ci"
    tag = "CiHardDrive"


class CiHashtag(rx.Component):
    library = "react-icons/ci"
    tag = "CiHashtag"


class CiHeadphones(rx.Component):
    library = "react-icons/ci"
    tag = "CiHeadphones"


class CiHeart(rx.Component):
    library = "react-icons/ci"
    tag = "CiHeart"


class CiHome(rx.Component):
    library = "react-icons/ci"
    tag = "CiHome"


class CiHospital1(rx.Component):
    library = "react-icons/ci"
    tag = "CiHospital1"


class CiHotdog(rx.Component):
    library = "react-icons/ci"
    tag = "CiHotdog"


class CiIceCream(rx.Component):
    library = "react-icons/ci"
    tag = "CiIceCream"


class CiImageOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiImageOff"


class CiImageOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiImageOn"


class CiImport(rx.Component):
    library = "react-icons/ci"
    tag = "CiImport"


class CiInboxIn(rx.Component):
    library = "react-icons/ci"
    tag = "CiInboxIn"


class CiInboxOut(rx.Component):
    library = "react-icons/ci"
    tag = "CiInboxOut"


class CiIndent(rx.Component):
    library = "react-icons/ci"
    tag = "CiIndent"


class CiInstagram(rx.Component):
    library = "react-icons/ci"
    tag = "CiInstagram"


class CiKeyboard(rx.Component):
    library = "react-icons/ci"
    tag = "CiKeyboard"


class CiLaptop(rx.Component):
    library = "react-icons/ci"
    tag = "CiLaptop"


class CiLemon(rx.Component):
    library = "react-icons/ci"
    tag = "CiLemon"


class CiLight(rx.Component):
    library = "react-icons/ci"
    tag = "CiLight"


class CiLineHeight(rx.Component):
    library = "react-icons/ci"
    tag = "CiLineHeight"


class CiLink(rx.Component):
    library = "react-icons/ci"
    tag = "CiLink"


class CiLinkedin(rx.Component):
    library = "react-icons/ci"
    tag = "CiLinkedin"


class CiLocationArrow1(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationArrow1"


class CiLocationOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationOff"


class CiLocationOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationOn"


class CiLock(rx.Component):
    library = "react-icons/ci"
    tag = "CiLock"


class CiLogin(rx.Component):
    library = "react-icons/ci"
    tag = "CiLogin"


class CiLogout(rx.Component):
    library = "react-icons/ci"
    tag = "CiLogout"


class CiLollipop(rx.Component):
    library = "react-icons/ci"
    tag = "CiLollipop"


class CiMail(rx.Component):
    library = "react-icons/ci"
    tag = "CiMail"


class CiMapPin(rx.Component):
    library = "react-icons/ci"
    tag = "CiMapPin"


class CiMap(rx.Component):
    library = "react-icons/ci"
    tag = "CiMap"


class CiMaximize1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMaximize1"


class CiMaximize2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMaximize2"


class CiMedal(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedal"


class CiMedicalCase(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalCase"


class CiMedicalClipboard(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalClipboard"


class CiMedicalCross(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalCross"


class CiMedicalMask(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalMask"


class CiMemoPad(rx.Component):
    library = "react-icons/ci"
    tag = "CiMemoPad"


class CiMenuBurger(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuBurger"


class CiMenuFries(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuFries"


class CiMenuKebab(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuKebab"


class CiMicrochip(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrochip"


class CiMicrophoneOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrophoneOff"


class CiMicrophoneOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrophoneOn"


class CiMinimize1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMinimize1"


class CiMinimize2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMinimize2"


class CiMobile1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile1"


class CiMobile2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile2"


class CiMobile3(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile3"


class CiMobile4(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile4"


class CiMoneyBill(rx.Component):
    library = "react-icons/ci"
    tag = "CiMoneyBill"


class CiMoneyCheck1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMoneyCheck1"


class CiMonitor(rx.Component):
    library = "react-icons/ci"
    tag = "CiMonitor"


class CiMountain1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMountain1"


class CiMug1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMug1"


class CiMusicNote1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMusicNote1"


class CiNoWaitingSign(rx.Component):
    library = "react-icons/ci"
    tag = "CiNoWaitingSign"


class CiPalette(rx.Component):
    library = "react-icons/ci"
    tag = "CiPalette"


class CiPaperplane(rx.Component):
    library = "react-icons/ci"
    tag = "CiPaperplane"


class CiParking1(rx.Component):
    library = "react-icons/ci"
    tag = "CiParking1"


class CiPassport1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPassport1"


class CiPause1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPause1"


class CiPen(rx.Component):
    library = "react-icons/ci"
    tag = "CiPen"


class CiPenpot(rx.Component):
    library = "react-icons/ci"
    tag = "CiPenpot"


class CiPercent(rx.Component):
    library = "react-icons/ci"
    tag = "CiPercent"


class CiPhone(rx.Component):
    library = "react-icons/ci"
    tag = "CiPhone"


class CiPickerEmpty(rx.Component):
    library = "react-icons/ci"
    tag = "CiPickerEmpty"


class CiPickerHalf(rx.Component):
    library = "react-icons/ci"
    tag = "CiPickerHalf"


class CiPill(rx.Component):
    library = "react-icons/ci"
    tag = "CiPill"


class CiPillsBottle1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPillsBottle1"


class CiPizza(rx.Component):
    library = "react-icons/ci"
    tag = "CiPizza"


class CiPlane(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlane"


class CiPlay1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlay1"


class CiPlug1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlug1"


class CiPower(rx.Component):
    library = "react-icons/ci"
    tag = "CiPower"


class CiRainbow(rx.Component):
    library = "react-icons/ci"
    tag = "CiRainbow"


class CiRead(rx.Component):
    library = "react-icons/ci"
    tag = "CiRead"


class CiReceipt(rx.Component):
    library = "react-icons/ci"
    tag = "CiReceipt"


class CiRedo(rx.Component):
    library = "react-icons/ci"
    tag = "CiRedo"


class CiRepeat(rx.Component):
    library = "react-icons/ci"
    tag = "CiRepeat"


class CiRollingSuitcase(rx.Component):
    library = "react-icons/ci"
    tag = "CiRollingSuitcase"


class CiRoute(rx.Component):
    library = "react-icons/ci"
    tag = "CiRoute"


class CiRouter(rx.Component):
    library = "react-icons/ci"
    tag = "CiRouter"


class CiRuler(rx.Component):
    library = "react-icons/ci"
    tag = "CiRuler"


class CiSatellite1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSatellite1"


class CiSaveDown1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveDown1"


class CiSaveDown2(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveDown2"


class CiSaveUp1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveUp1"


class CiSaveUp2(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveUp2"


class CiSearch(rx.Component):
    library = "react-icons/ci"
    tag = "CiSearch"


class CiServer(rx.Component):
    library = "react-icons/ci"
    tag = "CiServer"


class CiSettings(rx.Component):
    library = "react-icons/ci"
    tag = "CiSettings"


class CiShare1(rx.Component):
    library = "react-icons/ci"
    tag = "CiShare1"


class CiShare2(rx.Component):
    library = "react-icons/ci"
    tag = "CiShare2"


class CiShirt(rx.Component):
    library = "react-icons/ci"
    tag = "CiShirt"


class CiShop(rx.Component):
    library = "react-icons/ci"
    tag = "CiShop"


class CiShoppingBasket(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingBasket"


class CiShoppingCart(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingCart"


class CiShoppingTag(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingTag"


class CiShuffle(rx.Component):
    library = "react-icons/ci"
    tag = "CiShuffle"


class CiSignpostDuo1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostDuo1"


class CiSignpostL1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostL1"


class CiSignpostR1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostR1"


class CiSliderHorizontal(rx.Component):
    library = "react-icons/ci"
    tag = "CiSliderHorizontal"


class CiSliderVertical(rx.Component):
    library = "react-icons/ci"
    tag = "CiSliderVertical"


class CiSpeaker(rx.Component):
    library = "react-icons/ci"
    tag = "CiSpeaker"


class CiSquareAlert(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareAlert"


class CiSquareCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareCheck"


class CiSquareChevDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevDown"


class CiSquareChevLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevLeft"


class CiSquareChevRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevRight"


class CiSquareChevUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevUp"


class CiSquareInfo(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareInfo"


class CiSquareMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareMinus"


class CiSquareMore(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareMore"


class CiSquarePlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquarePlus"


class CiSquareQuestion(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareQuestion"


class CiSquareRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareRemove"


class CiStar(rx.Component):
    library = "react-icons/ci"
    tag = "CiStar"


class CiStethoscope(rx.Component):
    library = "react-icons/ci"
    tag = "CiStethoscope"


class CiStickyNote(rx.Component):
    library = "react-icons/ci"
    tag = "CiStickyNote"


class CiStop1(rx.Component):
    library = "react-icons/ci"
    tag = "CiStop1"


class CiStopSign1(rx.Component):
    library = "react-icons/ci"
    tag = "CiStopSign1"


class CiStopwatch(rx.Component):
    library = "react-icons/ci"
    tag = "CiStopwatch"


class CiStreamOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiStreamOff"


class CiStreamOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiStreamOn"


class CiSun(rx.Component):
    library = "react-icons/ci"
    tag = "CiSun"


class CiTablets1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTablets1"


class CiTempHigh(rx.Component):
    library = "react-icons/ci"
    tag = "CiTempHigh"


class CiTextAlignCenter(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignCenter"


class CiTextAlignJustify(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignJustify"


class CiTextAlignLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignLeft"


class CiTextAlignRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignRight"


class CiText(rx.Component):
    library = "react-icons/ci"
    tag = "CiText"


class CiTimer(rx.Component):
    library = "react-icons/ci"
    tag = "CiTimer"


class CiTrash(rx.Component):
    library = "react-icons/ci"
    tag = "CiTrash"


class CiTrophy(rx.Component):
    library = "react-icons/ci"
    tag = "CiTrophy"


class CiTurnL1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTurnL1"


class CiTurnR1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTurnR1"


class CiTwitter(rx.Component):
    library = "react-icons/ci"
    tag = "CiTwitter"


class CiUmbrella(rx.Component):
    library = "react-icons/ci"
    tag = "CiUmbrella"


class CiUndo(rx.Component):
    library = "react-icons/ci"
    tag = "CiUndo"


class CiUnlock(rx.Component):
    library = "react-icons/ci"
    tag = "CiUnlock"


class CiUnread(rx.Component):
    library = "react-icons/ci"
    tag = "CiUnread"


class CiUsb(rx.Component):
    library = "react-icons/ci"
    tag = "CiUsb"


class CiUser(rx.Component):
    library = "react-icons/ci"
    tag = "CiUser"


class CiVault(rx.Component):
    library = "react-icons/ci"
    tag = "CiVault"


class CiVial(rx.Component):
    library = "react-icons/ci"
    tag = "CiVial"


class CiVideoOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiVideoOff"


class CiVideoOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiVideoOn"


class CiViewBoard(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewBoard"


class CiViewColumn(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewColumn"


class CiViewList(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewList"


class CiViewTable(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewTable"


class CiViewTimeline(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewTimeline"


class CiVirus(rx.Component):
    library = "react-icons/ci"
    tag = "CiVirus"


class CiVoicemail(rx.Component):
    library = "react-icons/ci"
    tag = "CiVoicemail"


class CiVolumeHigh(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolumeHigh"


class CiVolumeMute(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolumeMute"


class CiVolume(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolume"


class CiWallet(rx.Component):
    library = "react-icons/ci"
    tag = "CiWallet"


class CiWarning(rx.Component):
    library = "react-icons/ci"
    tag = "CiWarning"


class CiWavePulse1(rx.Component):
    library = "react-icons/ci"
    tag = "CiWavePulse1"


class CiWheat(rx.Component):
    library = "react-icons/ci"
    tag = "CiWheat"


class CiWifiOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiWifiOff"


class CiWifiOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiWifiOn"


class CiYoutube(rx.Component):
    library = "react-icons/ci"
    tag = "CiYoutube"


class CiZoomIn(rx.Component):
    library = "react-icons/ci"
    tag = "CiZoomIn"


class CiZoomOut(rx.Component):
    library = "react-icons/ci"
    tag = "CiZoomOut"


